@@ -4,13 +4,13 @@ from trytond.config import config
 
 from .const import WGS_84
 
-__version__ = "6.4.0"
+__version__ = "7.6.1"
 
 
 class _GeoJSON(dict):
 
     def __init__(self, *args, **kwargs):
-        super(_GeoJSON, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         if 'meta' not in self:
             self['meta'] = {}
         if 'srid' not in self['meta']:
