@@ -1,11 +1,17 @@
 # This file is part of trytond_gis.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.backend.postgresql.database import (
-    DatabaseDataError, DatabaseIntegrityError, DatabaseOperationalError)
+    DatabaseDataError, DatabaseIntegrityError, DatabaseOperationalError,
+    DatabaseTimeoutError)
 
 from .database import Database
 from .table import TableHandler
 
 __all__ = [
-    Database, TableHandler,
-    DatabaseIntegrityError, DatabaseDataError, DatabaseOperationalError]
+    Database,
+    DatabaseIntegrityError,
+    DatabaseDataError,
+    DatabaseOperationalError,
+    DatabaseTimeoutError,
+    TableHandler,
+    ]
