@@ -1,19 +1,31 @@
 # This file is part of trytond_gis.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-import unittest
 
 from sql import Null
 
 from trytond.pool import Pool
-from trytond.tests.test_tryton import activate_module, with_transaction
+from trytond.tests.test_tryton import (
+    TestCase, activate_module, with_transaction)
 
 
-class TestGeographicFields(unittest.TestCase):
+class TestGeographicFields(TestCase):
 
     @classmethod
     def setUpClass(cls):
         activate_module('tests')
 
+    @with_transaction()
+    def test_fields_get(self):
+        "Test fields_get"
+        pool = Pool()
+
+        GISPoint = pool.get('test.gis.point')
+        point = {'dimension': 2, 'geometry_type': 'POINT'}
+        point = GISPoint.fields_get(['point'])['point']
+
+        self.assertEqual(point['dimension'], 2)
+        self.assertEqual(point['geometry_type'], 'POINT')
+
     @with_transaction()
     def test_create_save(self):
         "Testing create/write with GIS types"
@@ -28,7 +40,8 @@ class TestGeographicFields(unittest.TestCase):
         point, = GISPoint.create([{
                     'point': point_a,
                     }])
-        self.assertDictContainsSubset(point_a, point.point)
+        for key in point_a:
+            self.assertEqual(point.point[key], point_a[key])
 
         point_b = {
             'meta': {'srid': 4326},
@@ -39,7 +52,8 @@ class TestGeographicFields(unittest.TestCase):
         point.save()
 
         reload_point = GISPoint(point.id)
-        self.assertDictContainsSubset(point_b, reload_point.point)
+        for key in point_b:
+            self.assertEqual(reload_point.point[key], point_b[key])
 
         point.point = Null
         point.save()
@@ -77,7 +91,8 @@ class TestGeographicFields(unittest.TestCase):
                 ])
         self.assertEqual(len(points), 2)
         for point in points:
-            self.assertDictContainsSubset(point_a, point.point)
+            for key in point_a:
+                self.assertEqual(point.point[key], point_a[key])
 
         points = GISPoint.search([
                 ('point', '!=', point_a),
